# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.servingsite.v1 import servingsite_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2


class ServingSiteServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListServingSites = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService/ListServingSites',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.ListServingSitesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.ListServingSitesResponse.FromString,
                )
        self.CreateServingSite = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService/CreateServingSite',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.CreateServingSiteRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.CreateServingSiteResponse.FromString,
                )
        self.GetServingSite = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService/GetServingSite',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.GetServingSiteRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.GetServingSiteResponse.FromString,
                )
        self.UpdateServingSite = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService/UpdateServingSite',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.UpdateServingSiteRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.UpdateServingSiteResponse.FromString,
                )
        self.DeleteServingSite = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService/DeleteServingSite',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.DeleteServingSiteRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.DeleteServingSiteResponse.FromString,
                )
        self.GetPublicKey = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService/GetPublicKey',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.GetPublicKeyRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.GetPublicKeyResponse.FromString,
                )


class ServingSiteServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListServingSites(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateServingSite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServingSite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateServingSite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteServingSite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPublicKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ServingSiteServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListServingSites': grpc.unary_unary_rpc_method_handler(
                    servicer.ListServingSites,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.ListServingSitesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.ListServingSitesResponse.SerializeToString,
            ),
            'CreateServingSite': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateServingSite,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.CreateServingSiteRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.CreateServingSiteResponse.SerializeToString,
            ),
            'GetServingSite': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServingSite,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.GetServingSiteRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.GetServingSiteResponse.SerializeToString,
            ),
            'UpdateServingSite': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateServingSite,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.UpdateServingSiteRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.UpdateServingSiteResponse.SerializeToString,
            ),
            'DeleteServingSite': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteServingSite,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.DeleteServingSiteRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.DeleteServingSiteResponse.SerializeToString,
            ),
            'GetPublicKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPublicKey,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.GetPublicKeyRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.GetPublicKeyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ServingSiteService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListServingSites(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService/ListServingSites',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.ListServingSitesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.ListServingSitesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateServingSite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService/CreateServingSite',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.CreateServingSiteRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.CreateServingSiteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServingSite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService/GetServingSite',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.GetServingSiteRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.GetServingSiteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateServingSite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService/UpdateServingSite',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.UpdateServingSiteRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.UpdateServingSiteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteServingSite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService/DeleteServingSite',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.DeleteServingSiteRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.DeleteServingSiteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPublicKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.servingsite.v1.ServingSiteService/GetPublicKey',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.GetPublicKeyRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_servingsite_dot_v1_dot_servingsite__pb2.GetPublicKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/recipe/v1/recipe.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=github.com/metaprov/modelaapi/services/recipe/v1/recipe.proto\x12\x30github.com.metaprov.modelaapi.services.recipe.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xf1\x01\n\x12ListRecipesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12`\n\x06labels\x18\x02 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\x13ListRecipesResponse\x12Q\n\x07recipes\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x13\x43reateRecipeRequest\x12L\n\x06recipe\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x16\n\x14\x43reateRecipeResponse\"\x93\x01\n\x13UpdateRecipeRequest\x12L\n\x06recipe\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x16\n\x14UpdateRecipeResponse\"3\n\x10GetRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x87\x01\n\x14ProfileRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12N\n\x04spec\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeSpec\"c\n\x15ProfileRecipeResponse\x12J\n\x05table\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\x83\x01\n\x10RunRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12N\n\x04spec\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeSpec\"o\n\x11RunRecipeResponse\x12L\n\x06recipe\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"o\n\x11GetRecipeResponse\x12L\n\x06recipe\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"6\n\x13\x44\x65leteRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteRecipeResponse2\x8d\x0b\n\rRecipeService\x12\xbb\x01\n\x0bListRecipes\x12\x44.github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest\x1a\x45.github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/recipes/{namespace}\x12\xb5\x01\n\x0c\x43reateRecipe\x12\x45.github.com.metaprov.modelaapi.services.recipe.v1.CreateRecipeRequest\x1a\x46.github.com.metaprov.modelaapi.services.recipe.v1.CreateRecipeResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/recipes:\x01*\x12\xbc\x01\n\tGetRecipe\x12\x42.github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeRequest\x1a\x43.github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/recipes/{namespace}/{name}\x12\xc0\x01\n\tRunRecipe\x12\x42.github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeRequest\x1a\x43.github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/recipes/{namespace}/{name}:run\x12\xd0\x01\n\rProfileRecipe\x12\x46.github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeRequest\x1aG.github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/recipes/{namespace}/{name}:profile\x12\xe8\x01\n\x0cUpdateRecipe\x12\x45.github.com.metaprov.modelaapi.services.recipe.v1.UpdateRecipeRequest\x1a\x46.github.com.metaprov.modelaapi.services.recipe.v1.UpdateRecipeResponse\"I\x82\xd3\xe4\x93\x02\x43\x1a>/v1/recipes/{recipe.metadata.namespace}/{recipe.metadata.name}:\x01*\x12\xc5\x01\n\x0c\x44\x65leteRecipe\x12\x45.github.com.metaprov.modelaapi.services.recipe.v1.DeleteRecipeRequest\x1a\x46.github.com.metaprov.modelaapi.services.recipe.v1.DeleteRecipeResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1/recipes/{namespace}/{name}B2Z0github.com/metaprov/modelaapi/services/recipe/v1b\x06proto3')



_LISTRECIPESREQUEST = DESCRIPTOR.message_types_by_name['ListRecipesRequest']
_LISTRECIPESREQUEST_LABELSENTRY = _LISTRECIPESREQUEST.nested_types_by_name['LabelsEntry']
_LISTRECIPESRESPONSE = DESCRIPTOR.message_types_by_name['ListRecipesResponse']
_CREATERECIPEREQUEST = DESCRIPTOR.message_types_by_name['CreateRecipeRequest']
_CREATERECIPERESPONSE = DESCRIPTOR.message_types_by_name['CreateRecipeResponse']
_UPDATERECIPEREQUEST = DESCRIPTOR.message_types_by_name['UpdateRecipeRequest']
_UPDATERECIPERESPONSE = DESCRIPTOR.message_types_by_name['UpdateRecipeResponse']
_GETRECIPEREQUEST = DESCRIPTOR.message_types_by_name['GetRecipeRequest']
_PROFILERECIPEREQUEST = DESCRIPTOR.message_types_by_name['ProfileRecipeRequest']
_PROFILERECIPERESPONSE = DESCRIPTOR.message_types_by_name['ProfileRecipeResponse']
_RUNRECIPEREQUEST = DESCRIPTOR.message_types_by_name['RunRecipeRequest']
_RUNRECIPERESPONSE = DESCRIPTOR.message_types_by_name['RunRecipeResponse']
_GETRECIPERESPONSE = DESCRIPTOR.message_types_by_name['GetRecipeResponse']
_DELETERECIPEREQUEST = DESCRIPTOR.message_types_by_name['DeleteRecipeRequest']
_DELETERECIPERESPONSE = DESCRIPTOR.message_types_by_name['DeleteRecipeResponse']
ListRecipesRequest = _reflection.GeneratedProtocolMessageType('ListRecipesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTRECIPESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTRECIPESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest)
  })
_sym_db.RegisterMessage(ListRecipesRequest)
_sym_db.RegisterMessage(ListRecipesRequest.LabelsEntry)

ListRecipesResponse = _reflection.GeneratedProtocolMessageType('ListRecipesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesResponse)
  })
_sym_db.RegisterMessage(ListRecipesResponse)

CreateRecipeRequest = _reflection.GeneratedProtocolMessageType('CreateRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.CreateRecipeRequest)
  })
_sym_db.RegisterMessage(CreateRecipeRequest)

CreateRecipeResponse = _reflection.GeneratedProtocolMessageType('CreateRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.CreateRecipeResponse)
  })
_sym_db.RegisterMessage(CreateRecipeResponse)

UpdateRecipeRequest = _reflection.GeneratedProtocolMessageType('UpdateRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.UpdateRecipeRequest)
  })
_sym_db.RegisterMessage(UpdateRecipeRequest)

UpdateRecipeResponse = _reflection.GeneratedProtocolMessageType('UpdateRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.UpdateRecipeResponse)
  })
_sym_db.RegisterMessage(UpdateRecipeResponse)

GetRecipeRequest = _reflection.GeneratedProtocolMessageType('GetRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeRequest)
  })
_sym_db.RegisterMessage(GetRecipeRequest)

ProfileRecipeRequest = _reflection.GeneratedProtocolMessageType('ProfileRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROFILERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeRequest)
  })
_sym_db.RegisterMessage(ProfileRecipeRequest)

ProfileRecipeResponse = _reflection.GeneratedProtocolMessageType('ProfileRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROFILERECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeResponse)
  })
_sym_db.RegisterMessage(ProfileRecipeResponse)

RunRecipeRequest = _reflection.GeneratedProtocolMessageType('RunRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNRECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeRequest)
  })
_sym_db.RegisterMessage(RunRecipeRequest)

RunRecipeResponse = _reflection.GeneratedProtocolMessageType('RunRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNRECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeResponse)
  })
_sym_db.RegisterMessage(RunRecipeResponse)

GetRecipeResponse = _reflection.GeneratedProtocolMessageType('GetRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeResponse)
  })
_sym_db.RegisterMessage(GetRecipeResponse)

DeleteRecipeRequest = _reflection.GeneratedProtocolMessageType('DeleteRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.DeleteRecipeRequest)
  })
_sym_db.RegisterMessage(DeleteRecipeRequest)

DeleteRecipeResponse = _reflection.GeneratedProtocolMessageType('DeleteRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.DeleteRecipeResponse)
  })
_sym_db.RegisterMessage(DeleteRecipeResponse)

_RECIPESERVICE = DESCRIPTOR.services_by_name['RecipeService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/metaprov/modelaapi/services/recipe/v1'
  _LISTRECIPESREQUEST_LABELSENTRY._options = None
  _LISTRECIPESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _RECIPESERVICE.methods_by_name['ListRecipes']._options = None
  _RECIPESERVICE.methods_by_name['ListRecipes']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/recipes/{namespace}'
  _RECIPESERVICE.methods_by_name['CreateRecipe']._options = None
  _RECIPESERVICE.methods_by_name['CreateRecipe']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/recipes:\001*'
  _RECIPESERVICE.methods_by_name['GetRecipe']._options = None
  _RECIPESERVICE.methods_by_name['GetRecipe']._serialized_options = b'\202\323\344\223\002 \022\036/v1/recipes/{namespace}/{name}'
  _RECIPESERVICE.methods_by_name['RunRecipe']._options = None
  _RECIPESERVICE.methods_by_name['RunRecipe']._serialized_options = b'\202\323\344\223\002$\022\"/v1/recipes/{namespace}/{name}:run'
  _RECIPESERVICE.methods_by_name['ProfileRecipe']._options = None
  _RECIPESERVICE.methods_by_name['ProfileRecipe']._serialized_options = b'\202\323\344\223\002(\022&/v1/recipes/{namespace}/{name}:profile'
  _RECIPESERVICE.methods_by_name['UpdateRecipe']._options = None
  _RECIPESERVICE.methods_by_name['UpdateRecipe']._serialized_options = b'\202\323\344\223\002C\032>/v1/recipes/{recipe.metadata.namespace}/{recipe.metadata.name}:\001*'
  _RECIPESERVICE.methods_by_name['DeleteRecipe']._options = None
  _RECIPESERVICE.methods_by_name['DeleteRecipe']._serialized_options = b'\202\323\344\223\002 *\036/v1/recipes/{namespace}/{name}'
  _LISTRECIPESREQUEST._serialized_start=313
  _LISTRECIPESREQUEST._serialized_end=554
  _LISTRECIPESREQUEST_LABELSENTRY._serialized_start=509
  _LISTRECIPESREQUEST_LABELSENTRY._serialized_end=554
  _LISTRECIPESRESPONSE._serialized_start=557
  _LISTRECIPESRESPONSE._serialized_end=686
  _CREATERECIPEREQUEST._serialized_start=688
  _CREATERECIPEREQUEST._serialized_end=787
  _CREATERECIPERESPONSE._serialized_start=789
  _CREATERECIPERESPONSE._serialized_end=811
  _UPDATERECIPEREQUEST._serialized_start=814
  _UPDATERECIPEREQUEST._serialized_end=961
  _UPDATERECIPERESPONSE._serialized_start=963
  _UPDATERECIPERESPONSE._serialized_end=985
  _GETRECIPEREQUEST._serialized_start=987
  _GETRECIPEREQUEST._serialized_end=1038
  _PROFILERECIPEREQUEST._serialized_start=1041
  _PROFILERECIPEREQUEST._serialized_end=1176
  _PROFILERECIPERESPONSE._serialized_start=1178
  _PROFILERECIPERESPONSE._serialized_end=1277
  _RUNRECIPEREQUEST._serialized_start=1280
  _RUNRECIPEREQUEST._serialized_end=1411
  _RUNRECIPERESPONSE._serialized_start=1413
  _RUNRECIPERESPONSE._serialized_end=1524
  _GETRECIPERESPONSE._serialized_start=1526
  _GETRECIPERESPONSE._serialized_end=1637
  _DELETERECIPEREQUEST._serialized_start=1639
  _DELETERECIPEREQUEST._serialized_end=1693
  _DELETERECIPERESPONSE._serialized_start=1695
  _DELETERECIPERESPONSE._serialized_end=1717
  _RECIPESERVICE._serialized_start=1720
  _RECIPESERVICE._serialized_end=3141
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.predictionstore.v1 import predictionstore_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2


class PredictionStoreServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ingest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionStoreService/Ingest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2.PredictionsIngestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2.PredictionIngestResponse.FromString,
                )


class PredictionStoreServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Ingest(self, request, context):
        """upload the current prediction database to the cloud.
        The archived prediction will turn into a predicted dataset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PredictionStoreServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ingest': grpc.unary_unary_rpc_method_handler(
                    servicer.Ingest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2.PredictionsIngestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2.PredictionIngestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionStoreService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PredictionStoreService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Ingest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionStoreService/Ingest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2.PredictionsIngestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2.PredictionIngestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
